========
Commands
========

.. click:: coinflip.cli.commands:main
   :prog: coinflip

.. click:: coinflip.cli.commands:run
   :prog: coinflip run

.. click:: coinflip.cli.commands:example_run
   :prog: coinflip example-run

.. click:: coinflip.cli.commands:read
   :prog: coinflip read

.. click:: coinflip.cli.commands:report
   :prog: coinflip report
